/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_is extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AUD", "AUD" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BRL", "BRL" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "EUR", "EUR" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GBP", "GBP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "INR", "INR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRW", "KRW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "NZD", "NZD" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TWD", "TWD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "USD" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VND", "VND" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "adp", "Andorrskur peseti" },
            { "aed", "arab\u00edskt d\u00edrham" },
            { "afn", "afgani" },
            { "all", "albanskt lek" },
            { "amd", "armenskt dramm" },
            { "ang", "hollenskt Antillugyllini" },
            { "aoa", "ang\u00f3lsk kvansa" },
            { "ara", "Argentine Austral" },
            { "arp", "Argent\u00edskur pesi (1983\u20131985)" },
            { "ars", "argent\u00ednskur pesi" },
            { "ats", "Austurr\u00edskur skildingur" },
            { "aud", "\u00e1stralskur dalur" },
            { "awg", "ar\u00fab\u00f6nsk fl\u00f3r\u00edna" },
            { "azn", "aserskt manat" },
            { "bam", "skiptanlegt Bosn\u00edu og Herseg\u00f3v\u00ednu-mark" },
            { "bbd", "barbadoskur dalur" },
            { "bdt", "bangladessk taka" },
            { "bef", "Belg\u00edskur franki" },
            { "bgl", "Lef" },
            { "bgn", "b\u00falgarskt lef" },
            { "bhd", "bareinskur denari" },
            { "bif", "b\u00far\u00fand\u00edskur franki" },
            { "bmd", "Berm\u00fadadalur" },
            { "bnd", "br\u00faneiskur dalur" },
            { "bob", "b\u00f3liv\u00edani" },
            { "bop", "B\u00f3liv\u00edskur pesi" },
            { "bov", "Bolivian Mvdol" },
            { "brl", "brasil\u00edskt r\u00edal" },
            { "bsd", "Bahamadalur" },
            { "btn", "b\u00fatanskt n\u00faltrum" },
            { "buk", "B\u00farmverskt kjat" },
            { "bwp", "botsv\u00f6nsk p\u00fala" },
            { "byn", "hv\u00edtr\u00fassnesk r\u00fabla" },
            { "byr", "hv\u00edtr\u00fassnesk r\u00fabla (2000\u20132016)" },
            { "bzd", "bel\u00edskur dalur" },
            { "cad", "Kanadadalur" },
            { "cdf", "kong\u00f3skur franki" },
            { "chf", "svissneskur franki" },
            { "clf", "Chilean Unidades de Fomento" },
            { "clp", "s\u00edleskur pesi" },
            { "cnh", "k\u00ednverskt j\u00faan (utan heimalands)" },
            { "cny", "k\u00ednverskt j\u00faan" },
            { "cop", "k\u00f3lumb\u00edskur pesi" },
            { "crc", "kostar\u00edskt k\u00f3lon" },
            { "csk", "T\u00e9kknesk kr\u00f3na, eldri" },
            { "cuc", "k\u00fabverskur skiptanlegur pesi" },
            { "cup", "k\u00fabverskur pesi" },
            { "cve", "gr\u00e6nh\u00f6f\u00f0eyskur sk\u00fati" },
            { "cyp", "K\u00fdpverskt pund" },
            { "czk", "t\u00e9kknesk kr\u00f3na" },
            { "ddm", "Austur\u00fe\u00fdskt mark" },
            { "dem", "\u00de\u00fdskt mark" },
            { "djf", "dj\u00edb\u00fat\u00edskur franki" },
            { "dkk", "d\u00f6nsk kr\u00f3na" },
            { "dop", "d\u00f3min\u00edskur pesi" },
            { "dzd", "als\u00edrskur denari" },
            { "ecs", "Ecuador Sucre" },
            { "eek", "Eistnesk kr\u00f3na" },
            { "egp", "egypskt pund" },
            { "ern", "er\u00edtresk nakfa" },
            { "esp", "Sp\u00e6nskur peseti" },
            { "etb", "e\u00fe\u00ed\u00f3p\u00edskt birr" },
            { "eur", "evra" },
            { "fim", "Finnskt mark" },
            { "fjd", "fidjeyskur dalur" },
            { "fkp", "falklenskt pund" },
            { "frf", "Franskur franki" },
            { "gbp", "sterlingspund" },
            { "gel", "georg\u00edskur lari" },
            { "ghs", "ganverskur sedi" },
            { "gip", "G\u00edbraltarspund" },
            { "gmd", "gamb\u00edskur dalasi" },
            { "gnf", "G\u00edneufranki" },
            { "grd", "Drakma" },
            { "gtq", "gvatemalskt kvesal" },
            { "gwe", "Port\u00fagalskur, g\u00edneskur sk\u00fati" },
            { "gyd", "gv\u00e6janskur dalur" },
            { "hkd", "Hong Kong-dalur" },
            { "hnl", "hond\u00farsk lemp\u00edra" },
            { "hrk", "kr\u00f3at\u00edsk k\u00fana" },
            { "htg", "ha\u00edt\u00edskur g\u00fardi" },
            { "huf", "ungversk f\u00f3rinta" },
            { "idr", "ind\u00f3nes\u00edsk r\u00fap\u00eda" },
            { "iep", "\u00cdrskt pund" },
            { "ilp", "\u00cdsraelskt pund" },
            { "ils", "n\u00fdr \u00edsraelskur sikill" },
            { "inr", "indversk r\u00fap\u00eda" },
            { "iqd", "\u00edrakskur denari" },
            { "irr", "\u00edranskt r\u00edal" },
            { "isk", "\u00edslensk kr\u00f3na" },
            { "itl", "\u00cdt\u00f6lsk l\u00edra" },
            { "jmd", "jama\u00edskur dalur" },
            { "jod", "j\u00f3rdanskur denari" },
            { "jpy", "japanskt jen" },
            { "kes", "ken\u00edskur skildingur" },
            { "kgs", "kirgiskt som" },
            { "khr", "kamb\u00f3d\u00edskt r\u00edal" },
            { "kmf", "k\u00f3moreyskur franki" },
            { "kpw", "nor\u00f0urk\u00f3reskt vonn" },
            { "krw", "su\u00f0urk\u00f3reskt vonn" },
            { "kwd", "k\u00faveiskur denari" },
            { "kyd", "caymaneyskur dalur" },
            { "kzt", "kasakst tengi" },
            { "lak", "laoskt kip" },
            { "lbp", "l\u00edbanskt pund" },
            { "lkr", "sr\u00edl\u00f6nsk r\u00fap\u00eda" },
            { "lrd", "l\u00edber\u00edskur dalur" },
            { "lsl", "les\u00f3t\u00f3skur l\u00f3ti" },
            { "ltl", "Lith\u00e1\u00edskt l\u00edt" },
            { "ltt", "Lithuanian Talonas" },
            { "luf", "L\u00faxemborgarfranki" },
            { "lvl", "Lettneskt lat" },
            { "lvr", "Lettnesk r\u00fabla" },
            { "lyd", "l\u00edb\u00edskur denari" },
            { "mad", "marokk\u00f3skt d\u00edrham" },
            { "maf", "Marokk\u00f3skur franki" },
            { "mdl", "moldav\u00edskt lei" },
            { "mga", "Madagaskararjari" },
            { "mgf", "Madagaskur franki" },
            { "mkd", "maked\u00f3nskur denari" },
            { "mlf", "Mal\u00edskur franki" },
            { "mmk", "mjanmarskt kjat" },
            { "mnt", "mong\u00f3lskur t\u00far\u00edkur" },
            { "mop", "maka\u00f3sk pataka" },
            { "mro", "m\u00e1r\u00edt\u00f6nsk \u00fag\u00eda (1973\u20132017)" },
            { "mru", "m\u00e1r\u00edt\u00f6nsk \u00fag\u00eda" },
            { "mtl", "Meltnesk l\u00edra" },
            { "mtp", "Maltneskt pund" },
            { "mur", "m\u00e1rit\u00edsk r\u00fap\u00eda" },
            { "mvr", "mald\u00edveysk r\u00fap\u00eda" },
            { "mwk", "malav\u00edsk kvaka" },
            { "mxn", "mex\u00edk\u00f3skur pesi" },
            { "mxp", "Mex\u00edk\u00f3skur silfurpesi (1861\u20131992)" },
            { "mxv", "Mex\u00edk\u00f3skur pesi, UDI" },
            { "myr", "malas\u00edskt ringit" },
            { "mze", "M\u00f3samb\u00edskur sk\u00fati" },
            { "mzn", "m\u00f3samb\u00edskt metikal" },
            { "nad", "namib\u00edskur dalur" },
            { "ngn", "n\u00edger\u00edsk n\u00e6ra" },
            { "nic", "N\u00edkar\u00f6gsk kord\u00f3va (1988\u20131991)" },
            { "nio", "n\u00edkar\u00f6gsk kord\u00f3va" },
            { "nlg", "Hollenskt gyllini" },
            { "nok", "norsk kr\u00f3na" },
            { "npr", "nep\u00f6lsk r\u00fap\u00eda" },
            { "nzd", "n\u00fdsj\u00e1lenskur dalur" },
            { "omr", "\u00f3manskt r\u00edal" },
            { "pab", "balb\u00f3i" },
            { "pen", "per\u00faskt s\u00f3l" },
            { "pgk", "pap\u00fask k\u00edna" },
            { "php", "filippseyskur pesi" },
            { "pkr", "pakist\u00f6nsk r\u00fap\u00eda" },
            { "pln", "p\u00f3lskt slot" },
            { "plz", "Slot" },
            { "pte", "Port\u00fagalskur sk\u00fati" },
            { "pyg", "paragv\u00e6skt gvaran\u00ed" },
            { "qar", "katarskt r\u00edal" },
            { "rol", "R\u00famenskt lei (1952\u20132006)" },
            { "ron", "r\u00famenskt lei" },
            { "rsd", "serbneskur denari" },
            { "rub", "r\u00fassnesk r\u00fabla" },
            { "rur", "R\u00fassnesk r\u00fabla (1991\u20131998)" },
            { "rwf", "r\u00faandskur franki" },
            { "sar", "s\u00e1d\u00edarab\u00edskt r\u00edal" },
            { "sbd", "sal\u00f3monseyskur dalur" },
            { "scr", "Seychellesr\u00fap\u00eda" },
            { "sdd", "S\u00fadanskur denari" },
            { "sdg", "s\u00fadanskt pund" },
            { "sdp", "S\u00fadanskt pund (1957\u20131998)" },
            { "sek", "s\u00e6nsk kr\u00f3na" },
            { "sgd", "singap\u00farskur dalur" },
            { "shp", "helenskt pund" },
            { "sit", "Sl\u00f3venskur dalur" },
            { "skk", "Sl\u00f3vak\u00edsk kr\u00f3na" },
            { "sll", "s\u00ederrale\u00f3nsk lj\u00f3na" },
            { "sos", "s\u00f3mal\u00edskur skildingur" },
            { "srd", "S\u00far\u00ednamdalur" },
            { "srg", "Suriname Guilder" },
            { "ssp", "su\u00f0urs\u00fadanskt pund" },
            { "std", "Sa\u00f3 T\u00f3me og Prins\u00edpe-d\u00f3bra (1977\u20132017)" },
            { "stn", "Sa\u00f3 T\u00f3me og Prins\u00edpe-d\u00f3bra" },
            { "sur", "Soviet Rouble" },
            { "svc", "El Salvador Colon" },
            { "syp", "s\u00fdrlenskt pund" },
            { "szl", "svas\u00edlenskur l\u00edlangeni" },
            { "thb", "ta\u00edlenskt bat" },
            { "tjr", "Tadsjiksk r\u00fabla" },
            { "tjs", "tadsjikskur s\u00f3m\u00f3ni" },
            { "tmm", "T\u00farkmenskt manat (1993\u20132009)" },
            { "tmt", "t\u00farkmenskt manat" },
            { "tnd", "t\u00fan\u00edskur denari" },
            { "top", "Tongapanga" },
            { "tpe", "T\u00edmorskur sk\u00fati" },
            { "trl", "Tyrknesk l\u00edra (1922\u20132005)" },
            { "try", "tyrknesk l\u00edra" },
            { "ttd", "Tr\u00ednidad og T\u00f3bag\u00f3-dalur" },
            { "twd", "ta\u00edvanskur dalur" },
            { "tzs", "tansan\u00edskur skildingur" },
            { "uah", "\u00fakra\u00ednsk hrinja" },
            { "uak", "Ukrainian Karbovanetz" },
            { "ugx", "\u00fagandskur skildingur" },
            { "usd", "Bandar\u00edkjadalur" },
            { "usn", "Bandar\u00edkjadalur (n\u00e6sta dag)" },
            { "uss", "Bandar\u00edkjadalur (sama dag)" },
            { "uyu", "\u00far\u00fagv\u00e6skur pesi" },
            { "uzs", "\u00fasbekskt s\u00fam" },
            { "veb", "Bol\u00edvar \u00ed Venes\u00faela (1871\u20132008)" },
            { "vef", "venes\u00faelskur b\u00f3l\u00edvari (2008\u20132018)" },
            { "ves", "venes\u00faelskur b\u00f3l\u00edvari" },
            { "vnd", "v\u00edetnamskt dong" },
            { "vuv", "van\u00faat\u00faskt vat\u00fa" },
            { "wst", "Sam\u00f3atala" },
            { "xaf", "mi\u00f0afr\u00edskur franki" },
            { "xcd", "austurkarab\u00edskur dalur" },
            { "xdr", "S\u00e9rst\u00f6k dr\u00e1ttarr\u00e9ttindi" },
            { "xfo", "Franskur gullfranki" },
            { "xfu", "Franskur franki, UIC" },
            { "xof", "vesturafr\u00edskur franki" },
            { "xpf", "p\u00f3lines\u00edskur franki" },
            { "xxx", "\u00f3\u00feekktur gjaldmi\u00f0ill" },
            { "ydd", "Jemenskur denari" },
            { "yer", "jemenskt r\u00edal" },
            { "yum", "J\u00fag\u00f3slavneskur denari" },
            { "zal", "Rand (vi\u00f0skipta)" },
            { "zar", "su\u00f0urafr\u00edskt rand" },
            { "zmk", "Zambian Kwacha (1968\u20132012)" },
            { "zmw", "samb\u00edsk kvaka" },
            { "zwd", "Simbabveskur dalur" },
        };
        return data;
    }
}
